@@ -1,43 +1,47 @@
 import numpy as np
-import pykin.kinematics.transformation as tf
+
 from pykin.kinematics.transform import Transform
-from pykin.utils.shell_color import ShellColors as scolors
+from pykin.geometry.geometry import Visual, Collision
+from pykin.utils import transform_utils as tf
+from pykin.utils.kin_utils import ShellColors as scolors
+
 
 class Link:
-    def __init__(self, name=None, offset=Transform()):
+    def __init__(self, name=None, offset=Transform(), visual=Visual(), collision=Collision()):
         self.name = name
         self.offset = offset
+        self.visual = visual
+        self.collision = collision
+
     def __repr__(self):
         return f"""
-        {scolors.OKBLUE}Link{scolors.ENDC}( name= {scolors.HEADER}{self.name}{scolors.ENDC})"""
+        {scolors.OKBLUE}Link{scolors.ENDC}( name= {scolors.HEADER}{self.name}{scolors.ENDC}
+            offset= {scolors.HEADER}{self.offset}{scolors.ENDC}
+            visual= {scolors.HEADER}{self.visual}{scolors.ENDC} 
+            collision= {scolors.HEADER}{self.collision}{scolors.ENDC}"""
 
-    # @property
-    # def offset(self):
-    #     return self._offset
-
-    # @offset.setter
-    # def offset(self, offset):
-    #     self._offset = offset
 
 class Joint:
     TYPES = ['fixed', 'revolute', 'prismatic']
 
     def __init__(self, name=None, offset=Transform(),
-                 dtype='fixed', axis=None, parent=None, child=None):
+                 dtype='fixed', axis=None, limit=[None, None], parent=None, child=None):
         self.name = name
         self.offset = offset
-        self.parent = parent
-        self.child = child
         self.num_dof = 0
         self.dtype = dtype
         self.axis = np.array(axis)
- 
+        self.limit = limit
+        self.parent = parent
+        self.child = child
+
     def __repr__(self):
         return f"""
         {scolors.OKGREEN}Joint{scolors.ENDC}( name= {scolors.HEADER}{self.name}{scolors.ENDC} 
             offset= {scolors.HEADER}{self.offset}{scolors.ENDC}
             dtype= {scolors.HEADER}'{self.dtype}'{scolors.ENDC}
-            axis= {scolors.HEADER}{self.axis}{scolors.ENDC})"""
+            axis= {scolors.HEADER}{self.axis}{scolors.ENDC}
+            limit= {scolors.HEADER}{self.limit}{scolors.ENDC}"""
 
     @property
     def dtype(self):
@@ -66,14 +70,6 @@ class Joint:
     def num_dof(self, dof):
         self._num_dof = int(dof)
 
-    # @property
-    # def offset(self):
-    #     return self._offset
-
-    # @offset.setter
-    # def offset(self, offset):
-    #     self._offset = offset
-
 
 class Frame:
     def __init__(self, name=None, link=Link(),
